from enum import Enum
from typing import Optional, List
from datetime import datetime
from pydantic import BaseModel, EmailStr, Field

# Таблица для получения информации из запроса

class Role(Enum):
    OWNER = 'OWNER'
    ADMIN = 'ADMIN'
    EDITOR = 'EDITOR'
    VIEWER = 'VIEWER'

class Status(Enum):
    ACTIVE = 'ACTIVE'
    DISABLED = 'DISABLED'
    BLOCKED = 'BLOCKED'
    DELETED = 'DELETED'

class UserUpdate(BaseModel):
    id: Optional[int] = None
    name: Optional[str] = Field(None, max_length=100)
    login: Optional[str] = Field(None, max_length=100)
    email: Optional[EmailStr] = None
    bind_tenant_id: Optional[str] = Field(None, max_length=40)
    role: Optional[Role] = None
    meta: Optional[dict] = None
    creator_id: Optional[int] = None
    created_at: Optional[datetime] = None
    status: Optional[Status] = None

class AllUser(BaseModel):
    id: int
    login: str

class AllUserResponse(BaseModel):
    users: List[AllUser]
    amount_count: int
    amount_pages: int
